@@ -53,7 +53,7 @@ class Certificate(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["CertificateProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[CertificateProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: typing.Optional[builtins.bool] = None,
             ) -> None:
                 ...
@@ -209,7 +209,7 @@ class RosCertificate(
             def stub(
                 scope: ros_cdk_core.Construct,
                 id: builtins.str,
-                props: typing.Union["RosCertificateProps", typing.Dict[str, typing.Any]],
+                props: typing.Union[RosCertificateProps, typing.Dict[str, typing.Any]],
                 enable_resource_property_constraint: builtins.bool,
             ) -> None:
                 ...
